from setuptools import setup

setup(
    name='skellyai',
    version='0.2.3',    
    description='generated labeled data',
    author='Ben Nicholl',
    author_email='ben.nicholl66@gmail.com',
    license='BSD 2-clause',
    packages=['skellyai', 'skellyai/perform_inference', 'skellyai/get_multi_labels'],
    install_requires=[
                      'pandas==1.4.4',
                      'sagemaker==2.155.0'
                      ],

    classifiers=[
        'Development Status :: 1 - Planning',
        'Intended Audience :: Science/Research',
        'License :: OSI Approved :: BSD License',  
        'Operating System :: POSIX :: Linux',        
        "Programming Language :: Python :: 3"
    ],
)